@@ -1,27 +1,29 @@
 import os
 import ssl
-import imp
 import sys
 import signal
 import tornado.web
 import tornado.process
 import tornado.httpserver
 import tornado.autoreload
-from diraccfg import CFG
 
-import DIRAC
-
-from DIRAC import gLogger, gConfig
-from DIRAC.ConfigurationSystem.Client.Helpers import CSGlobals
+from DIRAC import gLogger, S_OK
 from WebAppDIRAC.Core.HandlerMgr import HandlerMgr
 from WebAppDIRAC.Core.TemplateLoader import TemplateLoader
 from WebAppDIRAC.Lib.SessionData import SessionData
 from WebAppDIRAC.Lib import Conf
 
-__RCSID__ = "$Id$"
+# If we are running with python3, Tornado will use asyncio,
+# and we have to convince it to let us run in a different thread
+# Doing this ensures a consistent behavior between py2 and py3
+# see https://www.tornadoweb.org/en/stable/asyncio.html#tornado.platform.asyncio.AnyThreadEventLoopPolicy
+import asyncio
+from tornado.platform.asyncio import AnyThreadEventLoopPolicy
+
+asyncio.set_event_loop_policy(AnyThreadEventLoopPolicy())
 
 
-class App(object):
+class App:
     def __init__(self, handlersLoc="WebApp.handler"):
         self.__handlerMgr = HandlerMgr(handlersLoc, Conf.rootURL())
         self.__servers = {}
@@ -56,6 +58,29 @@ class App(object):
         # gLogger.info('exit success')
         sys.exit(0)
 
+    def getAppToDict(self, port=None):
+        """Load Web portals
+
+        :return: S_OK(dict)/S_ERROR()
+        """
+        app = {"port": port or Conf.HTTPSPort()}
+        # Calculating routes
+        result = self.__handlerMgr.getRoutes()
+        if not result["OK"]:
+            return result
+        app["routes"] = result["Value"]
+        # Initialize the session data
+        SessionData.setHandlers(self.__handlerMgr.getHandlers()["Value"])
+        # Create the app
+        tLoader = TemplateLoader(self.__handlerMgr.getPaths("template"))
+        app["settings"] = dict(
+            debug=Conf.devMode(),
+            template_loader=tLoader,
+            cookie_secret=str(Conf.cookieSecret()),
+            log_function=self._logRequest,
+        )
+        return S_OK(app)
+
     def bootstrap(self):
         """
         Configure and create web app
@@ -108,7 +133,7 @@ class App(object):
                 keyfile=Conf.HTTPSKey(),
                 cert_reqs=ssl.CERT_OPTIONAL,
                 ca_certs=Conf.generateCAFile(),
-                ssl_version=ssl.PROTOCOL_TLSv1_2,
+                ssl_version="tls",
             )
 
             sslprotocol = str(Conf.SSLProtocol())
@@ -121,7 +146,7 @@ class App(object):
                     message += "The following protocols are provided: %s" % str(aviableProtocols)
                     gLogger.warn(message)
 
-            self.log.debug(" - %s" % "\n - ".join(["%s = %s" % (k, sslops[k]) for k in sslops]))
+            self.log.debug(" - %s" % "\n - ".join([f"{k} = {sslops[k]}" for k in sslops]))
             srv = tornado.httpserver.HTTPServer(self.__app, ssl_options=sslops, xheaders=True)
             port = Conf.HTTPSPort()
             srv.listen(port)
@@ -139,7 +164,7 @@ class App(object):
         bu = Conf.rootURL().strip("/")
         urls = []
         for proto, port in self.__servers:
-            urls.append("%s://0.0.0.0:%s/%s/" % (proto, port, bu))
+            urls.append(f"{proto}://0.0.0.0:{port}/{bu}/")
         self.log.always("Listening on %s" % " and ".join(urls))
         tornado.autoreload.add_reload_hook(self.__reloadAppCB)
         tornado.ioloop.IOLoop.instance().start()
