@@ -1,19 +1,14 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 
 from DIRAC import gConfig, gLogger
 from DIRAC.Core.Utilities import List
 from DIRAC.Core.DISET.AuthManager import AuthManager
-from DIRAC.Core.DISET.ThreadConfig import ThreadConfig
 from DIRAC.ConfigurationSystem.Client.Helpers import Registry
 from DIRAC.Core.Utilities.Extensions import extensionsByPriority
 
-from WebAppDIRAC.Lib import Conf
+# from DIRAC.FrameworkSystem.Client.ProxyManagerClient import gProxyManager
 
-__RCSID__ = "$Id$"
+from WebAppDIRAC.Lib import Conf
 
 DEFAULT_SCHEMA = [
     [
@@ -29,7 +24,6 @@ DEFAULT_SCHEMA = [
         "Applications",
         [
             ["app", "Accounting", "DIRAC.Accounting"],
-            ["app", "Activity Monitor", "DIRAC.ActivityMonitor"],
             ["app", "Configuration Manager", "DIRAC.ConfigurationManager"],
             ["app", "Job Monitor", "DIRAC.JobMonitor"],
             ["app", "Downtimes", "DIRAC.Downtimes"],
@@ -52,9 +46,8 @@ DEFAULT_SCHEMA = [
 ]
 
 
-class SessionData(object):
+class SessionData:
 
-    __disetConfig = ThreadConfig()
     __handlers = {}
     __groupMenu = {}
     __extensions = []
@@ -78,7 +71,10 @@ class SessionData(object):
                 cls.__extensions.append(cls.__extensions.pop(cls.__extensions.index(ext)))
 
     def __init__(self, credDict, setup):
-        self.__credDict = credDict
+        # Since cece7cc1 in DIRAC the full chain is stored in credDict
+        # This breaks the json.dumps in the various HTML templates so remove it
+        self.__credDict = dict(credDict)
+        self.__credDict.pop("x509Chain", None)
         self.__setup = setup
 
     def __isGroupAuthApp(self, appLoc):
@@ -93,11 +89,11 @@ class SessionData(object):
             gLogger.error("Application handler does not exists:", appLoc)
             return False
         if handlerLoc not in self.__handlers:
-            gLogger.error("Handler %s required by %s does not exist!" % (handlerLoc, appLoc))
+            gLogger.error(f"Handler {handlerLoc} required by {appLoc} does not exist!")
             return False
         handler = self.__handlers[handlerLoc]
         auth = AuthManager(Conf.getAuthSectionForHandler(handlerLoc))
-        gLogger.info("Authorization: %s -> %s" % (dict(self.__credDict), handler.AUTH_PROPS))
+        gLogger.info(f"Authorization: {dict(self.__credDict)} -> {handler.AUTH_PROPS}")
         return auth.authQuery("", dict(self.__credDict), handler.AUTH_PROPS)
 
     def __generateSchema(self, base, path):
@@ -110,13 +106,13 @@ class SessionData(object):
         """
         # Calculate schema
         schema = []
-        fullName = "%s/%s" % (base, path)
+        fullName = f"{base}/{path}"
         result = gConfig.getSections(fullName)
         if not result["OK"]:
             return schema
         sectionsList = result["Value"]
         for sName in sectionsList:
-            subSchema = self.__generateSchema(base, "%s/%s" % (path, sName))
+            subSchema = self.__generateSchema(base, f"{path}/{sName}")
             if subSchema:
                 schema.append((sName, subSchema))
         result = gConfig.getOptions(fullName)
@@ -124,8 +120,8 @@ class SessionData(object):
             return schema
         optionsList = result["Value"]
         for opName in optionsList:
-            opVal = gConfig.getValue("%s/%s" % (fullName, opName))
-            if opVal.find("link|") == 0:
+            opVal = gConfig.getValue(f"{fullName}/{opName}")
+            if opVal.startswith("link|"):
                 schema.append(("link", opName, opVal[5:]))  # pylint: disable=unsubscriptable-object
                 continue
             if self.__isGroupAuthApp(opVal):
@@ -206,17 +202,22 @@ class SessionData(object):
             "menu": self.__getGroupMenu(),
             "user": self.__credDict,
             "validGroups": [],
+            # 'groupsStatuses': '',
             "setup": self.__setup,
             "validSetups": gConfig.getSections("/DIRAC/Setups")["Value"],
             "extensions": self.__extensions,
             "extVersion": self.getExtJSVersion(),
         }
         # Add valid groups if known
-        DN = self.__credDict.get("DN", "")
-        if DN:
-            result = Registry.getGroupsForDN(DN)
-            if result["OK"]:
-                data["validGroups"] = result["Value"]
+        username = self.__credDict.get("username", "anonymous")
+        if username != "anonymous":
+            result = Registry.getGroupsForUser(username)
+            if not result["OK"]:
+                return result
+            data["validGroups"] = result["Value"]
+            # result = gProxyManager.getGroupsStatusByUsername(username)  # pylint: disable=no-member
+            # if result['OK']:
+            #   data['groupsStatuses'] = result['Value']
         # Calculate baseURL
         baseURL = [Conf.rootURL().strip("/"), "s:%s" % data["setup"], "g:%s" % self.__credDict.get("group", "")]
         data["baseURL"] = "/%s" % "/".join(baseURL)
