@@ -1,12 +1,14 @@
 #!/usr/bin/env python
-import imp
 import os
 import sys
 
-import six
-import tornado
+import tornado.iostream
+
+tornado.iostream.SSLIOStream.configure(
+    "tornado_m2crypto.m2iostream.M2IOStream"
+)  # pylint: disable=wrong-import-position
+
 from DIRAC import gConfig, S_OK
-from DIRAC.Core.Base import Script
 from DIRAC.Core.Utilities.Extensions import extensionsByPriority, getExtensionMetadata
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 from DIRAC.ConfigurationSystem.Client.LocalConfiguration import LocalConfiguration
@@ -30,27 +32,15 @@ def _createStaticSymlinks(targetDir):
         os.makedirs(targetDir)
     extensions = extensionsByPriority()
     for extension in extensions:
-        if six.PY3:
-            metadata = getExtensionMetadata(extension)
-            staticDirs = metadata.get("web_resources", {}).get("static", [])
-        else:
-            staticDirs = []
-            try:
-                modFile, modPath, desc = imp.find_module(extension)
-                # to match in the real root path to enabling module web extensions (static, templates...)
-                realModPath = os.path.realpath(modPath)
-            except ImportError:
-                continue
-            staticDirs = [os.path.join(realModPath, "WebApp", "static")]
-            if not os.path.isdir(staticDirs[0]):
-                continue
+        metadata = getExtensionMetadata(extension)
+        staticDirs = metadata.get("web_resources", {}).get("static", [])
 
         for i, path in enumerate(sorted(staticDirs)):
             destination = os.path.join(targetDir, extension)
             # If there is more than one suffix append a counter
             if i >= 1:
                 destination += "-%s" % i
-            gLogger.notice("    creating symlink from", "%s to %s" % (path, destination))
+            gLogger.notice("    creating symlink from", f"{path} to {destination}")
             if os.path.islink(destination):
                 if path == os.readlink(destination):
                     # The link is already up to date
@@ -84,14 +74,17 @@ def _checkDIRACVersion():
     dirac_spec = deps[0].specifier
     if dirac_version not in dirac_spec:
         raise RuntimeError(
-            "WebAppDIRAC %s requires %s but %s is incompatible" % (version("WebAppDIRAC"), dirac_version, dirac_spec)
+            "WebAppDIRAC {} requires {} but {} is incompatible".format(
+                version("WebAppDIRAC"), dirac_version, dirac_spec
+            )
         )
 
 
 @DIRACScript()
 def main():
-    if six.PY3:
-        _checkDIRACVersion()
+    def ignoreIncompatible(op):
+        gConfig.setOptionValue("/WebApp/IgnoreVersionCheck", "True")
+        return S_OK()
 
     def disableDevMode(op):
         gConfig.setOptionValue("/WebApp/DevelopMode", "False")
@@ -110,6 +103,7 @@ def main():
     localCfg.addDefaultEntry("/DIRAC/Security/UseServerCertificate", "yes")
     localCfg.addDefaultEntry("LogLevel", "INFO")
     localCfg.addDefaultEntry("LogColor", True)
+    localCfg.registerCmdOpt("i", "--ignore-incompatible", "Ignore incompatible version.", ignoreIncompatible)
     localCfg.registerCmdOpt("p", "production", "Enable production mode", disableDevMode)
     localCfg.registerCmdOpt(
         "S:",
@@ -124,6 +118,9 @@ def main():
         gLogger.fatal("There were errors when loading configuration", result["Message"])
         sys.exit(1)
 
+    if gConfig.getOption("/WebApp/IgnoreVersionCheck").get("Value", "").lower() not in ["yes", "true"]:
+        _checkDIRACVersion()
+
     result = gConfig.getOption("/WebApp/StaticResourceLinkDir")
     if result["OK"]:
         gLogger.notice("Creating symlinks to static resources")
